@@ -103,6 +103,7 @@
 /* Libraries */
 /* #undef HAVE_LIBWRAP */
 #define HAVE_SYSTEMD 1
+#define HAVE_SYSTEMD_SD_LISTEN_FDS_WITH_NAMES 1
 
 /* Does "struct timespec" have a "sec" and "nsec" field? */
 /* #undef HAVE_TIMESPEC_TS_SEC */
@@ -428,7 +429,7 @@
 #define PSAPI_VERSION 1     /* for GetProcessMemoryInfo() */
 
 /* We don't want the min/max macros */
-#ifdef __WIN__
+#ifdef _WIN32
 #define NOMINMAX 1
 #endif
 
@@ -527,17 +528,17 @@
 /* #undef SO_EXT */
 
 #define MYSQL_VERSION_MAJOR 10
-#define MYSQL_VERSION_MINOR 5
-#define MYSQL_VERSION_PATCH 11
+#define MYSQL_VERSION_MINOR 6
+#define MYSQL_VERSION_PATCH 3
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.5.11"
+#define PACKAGE_STRING "MySQL Server 10.6.3"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.5.11"
-#define VERSION "10.5.11"
+#define PACKAGE_VERSION "10.6.3"
+#define VERSION "10.6.3"
 #define PROTOCOL_VERSION 10
 #define PCRE2_CODE_UNIT_WIDTH 8
 
